package com.fs.qw.service.impl;

import java.util.List;

import com.fs.qw.domain.CustomerTransferApproval;
import com.fs.qw.mapper.CustomerTransferApprovalMapper;
import com.fs.qw.service.ICustomerTransferApprovalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 客户转移审批Service业务层处理
 *
 * @author fs
 * @date 2025-04-01
 */
@Service
public class CustomerTransferApprovalServiceImpl implements ICustomerTransferApprovalService
{
    @Autowired
    private CustomerTransferApprovalMapper customerTransferApprovalMapper;

    /**
     * 查询客户转移审批
     *
     * @param id 客户转移审批ID
     * @return 客户转移审批
     */
    @Override
    public CustomerTransferApproval selectCustomerTransferApprovalById(Long id)
    {
        return customerTransferApprovalMapper.selectCustomerTransferApprovalById(id);
    }

    /**
     * 查询客户转移审批列表
     *
     * @param customerTransferApproval 客户转移审批
     * @return 客户转移审批
     */
    @Override
    public List<CustomerTransferApproval> selectCustomerTransferApprovalList(CustomerTransferApproval customerTransferApproval)
    {
        return customerTransferApprovalMapper.selectCustomerTransferApprovalList(customerTransferApproval);
    }

    /**
     * 新增客户转移审批
     *
     * @param customerTransferApproval 客户转移审批
     * @return 结果
     */
    @Override
    public int insertCustomerTransferApproval(CustomerTransferApproval customerTransferApproval)
    {
        return customerTransferApprovalMapper.insertCustomerTransferApproval(customerTransferApproval);
    }

    /**
     * 修改客户转移审批
     *
     * @param customerTransferApproval 客户转移审批
     * @return 结果
     */
    @Override
    public int updateCustomerTransferApproval(CustomerTransferApproval customerTransferApproval)
    {
        return customerTransferApprovalMapper.updateCustomerTransferApproval(customerTransferApproval);
    }

    /**
     * 批量删除客户转移审批
     *
     * @param ids 需要删除的客户转移审批ID
     * @return 结果
     */
    @Override
    public int deleteCustomerTransferApprovalByIds(Long[] ids)
    {
        return customerTransferApprovalMapper.deleteCustomerTransferApprovalByIds(ids);
    }

    /**
     * 删除客户转移审批信息
     *
     * @param id 客户转移审批ID
     * @return 结果
     */
    @Override
    public int deleteCustomerTransferApprovalById(Long id)
    {
        return customerTransferApprovalMapper.deleteCustomerTransferApprovalById(id);
    }
}
